@@ -469,7 +469,7 @@ class HardwareIOTypeForm(forms.Form):
         fields = ['type', 'parent_hardware', 'child_hardware', 'child_channel', 'hub']
 
 
-from django.forms.models import inlineformset_factory, BaseForm
+from django.forms.models import inlineformset_factory, BaseModelFormSet, BaseInlineFormSet
 from data.models.models import HardwareStats, DataTransformer, DataTransformerConstants, HardwareDataTransformer, \
     HardwareStatsDataTransformer
 
@@ -480,7 +480,7 @@ HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, Hardwa
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,exclude =['updated_at','created_at'])
 
 
-class DataTransformerForm(forms.ModelForm):
+class DataTransformerForm(BaseInlineFormSet,BaseModelFormSet):
     def __init__(self, *args, **kwargs):
         super(DataTransformerForm, self).__init__(*args, **kwargs)
 
@@ -492,7 +492,7 @@ class DataTransformerForm(forms.ModelForm):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        form.nested_data_transformer_form = DataTransformerInlineFormset(
+        form.nested_data_transformer_form = DataTransformerForm(
             instance=form.instance,
             data=form.data if form.is_bound else None,
             files=form.files if form.is_bound else None,
